SecretKeyRef

Struct SecretKeyRef 

pub struct SecretKeyRef<'a> { /* private fields */ }
A SecretKey reference wrapper.

A wrapper around secp256k1::SecretKey reference, which enables it to be used in methods expecting Key capabilities.

Implementations

Source

impl<'a> SecretKeyRef<'a>

pub fn new(key: &'a SecretKey) -> Self

A simple wrapper around a reference to SecretKey which allows it to be usable for signing.

Methods from Deref<Target = SecretKey>

pub fn as_ptr(&self) -> *const u8

Converts the object to a raw pointer for FFI interfacing

pub fn len(&self) -> usize

Returns the length of the object as an array

pub fn is_empty(&self) -> bool

Returns whether the object as an array is empty